@@ -4,24 +4,24 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -69,19 +69,19 @@ namespace ost {
  * under APE.  A serial is a system serial port that is used either
  * for line or packet based data input.  Serial ports may also be
  * "streamable" in a derived form.
- * 
+ *
  *  Common C++ serial I/O classes are used to manage serial devices and
  *  implement serial device protocols.  From the point of view of Common C++,
  *  serial devices are supported by the underlying Posix specified "termios"
  *  call interface.
- * 
+ *
  *  The serial I/O base class is used to hold a descriptor to a serial device
  *  and to provide an exception handling interface for all serial I/O classes.
  *  The base class is also used to specify serial I/O properties such as
  *  communication speed, flow control, data size, and parity.  The "Serial"
  *  base class is not itself directly used in application development,
  *  however.
- * 
+ *
  *  Common C++ Serial I/O is itself divided into two conceptual modes; frame
  *  oriented and line oriented I/O.  Both frame and line oriented I/O makes
  *  use of the ability of the underlying tty driver to buffer data and return
@@ -97,8 +97,7 @@ namespace ost {
 class __EXPORT Serial
 {
 public:
-	enum Error
-	{
+	enum Error {
 		errSuccess = 0,
 		errOpenNoTty,
 		errOpenFailed,
@@ -116,8 +115,7 @@ public:
 	};
 	typedef enum Error Error;
 
-	enum Flow
-	{
+	enum Flow {
 		flowNone,
 		flowSoft,
 		flowHard,
@@ -125,16 +123,14 @@ public:
 	};
 	typedef enum Flow Flow;
 
-	enum Parity
-	{
+	enum Parity {
 		parityNone,
 		parityOdd,
 		parityEven
 	};
 	typedef enum Parity Parity;
 
-	enum Pending
-	{
+	enum Pending {
 		pendingInput,
 		pendingOutput,
 		pendingError
@@ -145,8 +141,7 @@ private:
 	Error errid;
 	char *errstr;
 
-	struct
-	{
+	struct {
 		bool thrown: 1;
 		bool linebuf: 1;
 	} flags;
@@ -406,7 +401,7 @@ public:
 /**
  * TTY streams are used to represent serial connections that are fully
  * "streamable" objects using C++ stream classes and friends.
- * 
+ *
  * The first application relevant serial I/O class is the TTYStream class.
  * TTYStream offers a linearly buffered "streaming" I/O session with the
  * serial device.  Furthermore, traditional C++ "stream" operators (<< and
@@ -415,11 +410,11 @@ public:
  * in which one can pass initial serial device parameters immediately
  * following the device name in a single string, as in
  * "/dev/tty3a:9600,7,e,1", as an example.
- * 
+ *
  * The TTYSession aggragates a TTYStream and a Common C++ Thread which is
  * assumed to be the execution context that will be used to perform actual
  * I/O operations.  This class is very anagolous to TCPSession.
- * 
+ *
  *
  * @author David Sugar <dyfet@ostel.com>
  * @short streamable tty serial I/O class.
@@ -511,14 +506,14 @@ public:
 	 * @param flag bool set to true to make interactive.
 	 */
 	void interactive(bool flag);
-	
+
 	/**
 	 * Flushes the stream input and out buffers, writes
 	 * pending output.
 	 *
 	 * @return 0 on success.
 	 */
-	int sync(void);	
+	int sync(void);
 
 	/**
 	 * Get the status of pending operations.  This can be used to
@@ -532,7 +527,7 @@ public:
 	 * @param timeout in milliseconds.
 	 */
 	bool isPending(Pending pend, timeout_t timeout = TIMEOUT_INF);
-};	
+};
 
 /**
  * A more natural C++ "ttystream" class for use by non-threaded
@@ -580,11 +575,11 @@ public:
 };
 
 /**
- * 
+ *
  * The TTYSession aggragates a TTYStream and a Common C++ Thread which is
  * assumed to be the execution context that will be used to perform actual
  * I/O operations.  This class is very anagolous to TCPSession.
- * 
+ *
  * @author David Sugar <dyfet@ostel.com>
  * @short This class is very anagolous to TCPSession.
  */
@@ -626,8 +621,8 @@ class __EXPORT SerialService;
  * event management, whereby the service thread performs a "callback" into
  * the port object when events occur.  Specific events supported include the
  * expiration of a TTYPort timer, pending input data waiting to be read, and
- * "sighup" connection breaks.   
- * 
+ * "sighup" connection breaks.
+ *
  *
  * @author David Sugar <dyfet@ostel.com>
  * @short base class for thread pool serviced serial I/O.
@@ -654,7 +649,7 @@ protected:
 	 * @param name of tty port.
 	 */
 	SerialPort(SerialService *svc, const char *name);
-	
+
 	/**
 	 * Disconnect the Serial Port from the service pool thread
 	 * and shutdown the port.
@@ -666,19 +661,19 @@ protected:
 	 * data for us.
 	 */
 	void setDetectPending( bool );
-	
+
 	/**
 	 * Get the current state of the DetectPending flag.
 	 */
 	inline bool getDetectPending( void ) const
 		{ return detect_pending; }
-	
+
 	/**
 	 * Used to indicate if output ready monitoring should be performed
 	 * by the service thread.
 	 */
 	void setDetectOutput( bool );
-	
+
 	/**
 	 * Get the current state of the DetectOutput flag.
 	 */
@@ -756,7 +751,7 @@ public:
  * multiple serial ports may be attached to the same thread of
  * of execution.  This allows one to balance threads and the serial ports
  * they service.
- * 
+ *
  *  The TTYPort and TTYService classes are used to form thread-pool serviced
  *  serial I/O protocol sets.  These can be used when one has a large number
  *  of serial devices to manage, and a single (or limited number of) thread(s)
@@ -766,7 +761,7 @@ public:
  *  event management, whereby the service thread performs a "callback" into
  *  the port object when events occur.  Specific events supported include the
  *  expiration of a TTYPort timer, pending input data waiting to be read, and
- *  "sighup" connection breaks.   
+ *  "sighup" connection breaks.
  *
  *
  * @author David Sugar <dyfet@ostel.com>
