@@ -4,7 +4,7 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -13,15 +13,15 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -62,14 +62,14 @@ namespace ost {
  * to a string containing a number of possible delimiters.
  * The StringTokenizer provides an input forward iterator which allows
  * to iterate through all tokens. An iterator behaves like a logical
- * pointer to the tokens, i.e. to shift to the next token, you've 
+ * pointer to the tokens, i.e. to shift to the next token, you've
  * to increment the iterator, you get the token by dereferencing the
  * iterator.
  *
  * Memory consumption:
  * This class operates on the original string and only allocates memory
- * for the individual tokens actually requested, so this class 
- * allocates at maximum the space required for the longest token in the 
+ * for the individual tokens actually requested, so this class
+ * allocates at maximum the space required for the longest token in the
  * given string.
  * Since for each iteration, memory is reclaimed for the last token,
  * you MAY NOT store pointers to them; if you need them afterwards,
@@ -133,7 +133,7 @@ public:
 		char *token;            // allocated token, if requested
 
 		// for initialization of the itEnd iterator
-		iterator(const StringTokenizer &tok, const char *end) 
+		iterator(const StringTokenizer &tok, const char *end)
 			: myTok(&tok),tokEnd(0),endp(end),token(0) {}
 
 		iterator(const StringTokenizer &tok)
@@ -145,8 +145,9 @@ public:
 		iterator() : myTok(0),start(0),tokEnd(0),endp(0),token(0) {}
 
 		// see also: comment in implementation of operator++
-		virtual ~iterator() { if (token) *token='\0'; delete [] token; }
-		
+		virtual ~iterator() 
+			{ if (token) *token='\0'; delete [] token; }
+
 		/**
 		 * copy constructor.
 		 */
@@ -159,8 +160,9 @@ public:
 		 * assignment operator.
 		 */
 		// everything, but not responsible for the allocated token.
-		iterator &operator = (const iterator &i) {
-			myTok = i.myTok; 
+		iterator &operator = (const iterator &i) 
+		{
+			myTok = i.myTok;
 			start = i.start; endp = i.endp; tokEnd = i.tokEnd;
 			if ( token )
 				delete [] token;
@@ -182,34 +184,31 @@ public:
 		 * copy it (e.g. with strdup());
 		 */
 		const char*  operator *  () THROWS (NoSuchElementException);
-		
+
 		/**
 		 * returns the next delimiter after the current token or
 		 * '\\0', if there are no following delimiters.
-		 * It returns the very next delimiter (even if 
+		 * It returns the very next delimiter (even if
 		 * skipAllDelim=true).
 		 */
-		inline char nextDelimiter() const {
-			return (tokEnd) ? *tokEnd : '\0';
-		}
-		
+		inline char nextDelimiter() const 
+			{return (tokEnd) ? *tokEnd : '\0';}
+
 		/**
 		 * compares to other iterator. Usually used to
 		 * compare against the end() iterator.
 		 */
 		// only compare the end-position. speed.
-		inline bool operator == (const iterator &other) const { 
-			return (endp == other.endp);
-		}
+		inline bool operator == (const iterator &other) const 
+			{return (endp == other.endp);}
 
 		/**
 		 * compares to other iterator. Usually used to
 		 * compare against the end() iterator.
 		 */
 		// only compare the end position. speed.
-		inline bool operator != (const iterator &other) const { 
-			return (endp != other.endp);
-		}
+		inline bool operator != (const iterator &other) const 
+			{return (endp != other.endp);}
 	};
 private:
 	friend class StringTokenizer::iterator;
@@ -232,7 +231,7 @@ public:
 	 * @param  delim        String containing the characters
 	 *                      which should be regarded as delimiters.
 	 *
-	 * @param  skipAllDelim OPTIONAL. 
+	 * @param  skipAllDelim OPTIONAL.
 	 *                      true, if subsequent
 	 *                      delimiters should be skipped at once
 	 *                      or false, if empty tokens should
@@ -242,18 +241,18 @@ public:
 	 *                      skipping, the second for input with
 	 *                      delimited entry e.g. /etc/passwd like files
 	 *                      or CSV input.
-	 *                      NOTE, that 'true' here resembles the 
+	 *                      NOTE, that 'true' here resembles the
 	 *                      ANSI-C strtok(char *s,char *d) behaviour.
 	 *                      DEFAULT = false
 	 *
-	 * @param trim          OPTIONAL. 
+	 * @param trim          OPTIONAL.
 	 *                      true, if the tokens returned
 	 *                      should be trimmed, so that they don't have
 	 *                      any whitespaces at the beginning or end.
-	 *                      Whitespaces are any of the characters 
+	 *                      Whitespaces are any of the characters
 	 *                      defined in StringTokenizer::SPACE.
 	 *                      If delim itself is StringTokenizer::SPACE,
-	 *                      this will result in a behaviour with 
+	 *                      this will result in a behaviour with
 	 *                      skipAllDelim = true.
 	 *                      DEFAULT = false
 	 */
@@ -261,7 +260,7 @@ public:
 			 const char *delim,
 			 bool skipAllDelim = false,
 			 bool trim = false);
-	
+
 	/**
 	 * create a new StringTokenizer which splits the input
 	 * string at whitespaces. The tokens are stripped from
@@ -276,23 +275,22 @@ public:
 	/**
 	 * returns the begin iterator
 	 */
-	iterator begin() const { 
-		return iterator(*this);
-	}
-	
+	iterator begin() const 
+		{return iterator(*this);}
+
 	/**
 	 * changes the set of delimiters used in subsequent
 	 * iterations.
 	 */
-	void setDelimiters (const char *d) {
-		delim = d;
-	}
-	
+	void setDelimiters (const char *d) 
+		{delim = d;}
+
 	/**
-	 * returns a begin iterator with an alternate set of 
+	 * returns a begin iterator with an alternate set of
 	 * delimiters.
 	 */
-	iterator begin(const char *d) { 
+	iterator begin(const char *d) 
+	{
 		delim = d;
 		return iterator(*this);
 	}
@@ -300,7 +298,8 @@ public:
 	/**
 	 * the iterator marking the end.
 	 */
-	const iterator& end() const { return itEnd; }
+	const iterator& end() const 
+		{return itEnd;}
 };
 
 #ifdef	CCXX_NAMESPACES
